pub enum EntityProviderError {
General(Box<dyn Error + Send + Sync + 'static>),
}Expand description
EntityProviderError is a general error that any implementation of trait
SimpleEntityProvider can return as an error.
Variants
General(Box<dyn Error + Send + Sync + 'static>)
General error case, designed to be used with any source std error.