#[repr(u8)]pub enum ReputationScoreId {
Unknown = 0,
VerySafe = 1,
Safe = 2,
ProbablySafe = 3,
LeansSafe = 4,
MayNotBeSafe = 5,
ExerciseCaution = 6,
SuspiciousRisky = 7,
PossiblyMalicious = 8,
ProbablyMalicious = 9,
Malicious = 10,
Other = 99,
}Expand description
The Reputation object describes the reputation/risk score of an entity (e.g. device, user, domain)
Variants
Unknown = 0
Unknown
VerySafe = 1
Long history of good behavior
Safe = 2
Consistently good behavior
ProbablySafe = 3
No bad behavior
LeansSafe = 4
Reasonable history of good behavior
MayNotBeSafe = 5
Starting to establish a history behavior
ExerciseCaution = 6
No established history of normal behavior
SuspiciousRisky = 7
Starting to establish a history of suspicious or risky behavior
PossiblyMalicious = 8
A site with a history of suspicious or risky behavior. (spam, scam, potentially unwanted software, potentially malicious)
ProbablyMalicious = 9
Strong possibility of maliciousness
Malicious = 10
Indicators of maliciousness
Other = 99
Proven evidence of maliciousness