pub struct Reputation {
pub score_id: ReputationScoreId,
pub base_score: u8,
pub provider: Option<String>,
pub score: Option<String>,
}Expand description
Describes the reputation/risk score of an entity (e.g. device, user, domain). https://schema.ocsf.io/1.0.0/objects/reputation?extensions=
Fields
score_id: ReputationScoreIdThe normalized reputation score identifier
base_score: u8The reputation score as reported by the event source
provider: Option<String>The provider of the reputation information
score: Option<String>The reputation score, normalized to the caption of the score_id value. In the case of ‘Other’,
it is defined by the event source