Config

Struct Config 

pub struct Config {
    pub format: Format,
    pub field_set: FieldSet,
    pub requester: String,
}
This structure is used to configure the logging system by specifying the log file directory, log file name prefix, log rotation strategy, log rotation format, and meter provider.

Fields

format: Format

format is used to specify the log rotation format. By default the log rotation format is OpenCyberSecurityFramework (OCSF).

field_set: FieldSet

A set specifying which fields are opted-in to be logged

requester: String

A requester name is used to provide the name of the product and separate the log from different authorizers