FieldSet

Struct FieldSet 

pub struct FieldSet {
    pub principal: bool,
    pub resource: bool,
    pub action: bool,
    pub context: bool,
    pub entities: FieldLevel<Entities>,
}
The FieldSet specifies which fields are to be logged

Fields

principal: bool

A boolean specifying whether the principal field is to be logged

resource: bool

A boolean specifying whether the resource field is to be logged

action: bool

A boolean specifying whether the action field is to be logged

context: bool

A boolean specifying whether the context field is to be logged

entities: FieldLevel<Entities>

A variant of the FieldLevel enum specifying which entity fields are to be logged