pub struct FieldSet {
pub principal: bool,
pub resource: bool,
pub action: bool,
pub context: bool,
pub entities: FieldLevel<Entities>,
}Expand description
The FieldSet specifies which fields are to be logged
Fields
principal: boolA boolean specifying whether the principal field is to be logged
resource: boolA boolean specifying whether the resource field is to be logged
action: boolA boolean specifying whether the action field is to be logged
context: boolA boolean specifying whether the context field is to be logged
entities: FieldLevel<Entities>A variant of the FieldLevel enum specifying which entity fields are to be logged